@@ -21,16 +21,15 @@
 #'
 create_weighting <- function(dataset, ...){
 
-  # data set content: Y, w, gps, counter, row_index, c
+  # data set content: Y, w, gps, counter_weight, row_index, c
 
-  if (sum(!is.element(c("Y","w","gps","counter","row_index"),
+  if (sum(!is.element(c("Y","w","gps","counter_weight","row_index"),
                       colnames(dataset)))> 0){
     stop("Dataset does not include all required columns.")
   }
 
   Nm <- compute_density(dataset[["w"]], dataset[["w"]])
   ipw <- Nm / (dataset[["gps"]])
-  return(data.table::data.table(cbind(dataset[,c("Y","w","gps",
-                                                 "counter","row_index")],
-                          ipw, dataset[,6:length(dataset)])))
+  dataset$counter_weight <- ipw
+  return(data.table::data.table(dataset))
 }
